/*
 *	Copyright (C) 2007, 2008. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvnumericplot.cpp
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#include <iostream>
#include <qvgui/qvnumericplot.h>

QVNumericPlot::QVNumericPlot(const QString name, bool time, int step, QWidget *parent): QVPlot(name, true, false, false, true, time, step, parent)
	{ }

bool QVNumericPlot::linkProperty(QVWorker &worker, const QString propertyName)
	{
	int propType = worker.getPropertyType(propertyName);

	if ( (propType != QVariant::Int) && (propType != QVariant::Double) ) {
		std::cerr << "Warning: a numericplot only can be linked to a int or double property." << std::endl;
		return false;
	}
	else
		return QVPlot::linkProperty(worker, propertyName);
	}

void QVNumericPlot::linkProperty(QVWorker &worker)
	{
	QStringList inputProper = worker.getPropertyListByType<int>() + worker.getPropertyListByType<double>();
	for (int i = 0; i < inputProper.size(); i++)
		if (worker.isOutput(inputProper[i])) // si la propiedad es de salida
			linkProperty(worker, inputProper[i]);
	}

QStringList QVNumericPlot::getPropertyCurvNames(QString property) const
	{
	return (QStringList() << property);
	}

QList<double> QVNumericPlot::getPropertyCurvValues(QString property) const
	{
	int propType = getPropertyType(property);

	QList<double> value;
	if (propType == QVariant::Int)
		value << getPropertyValue<int>(property);
	else if (propType == QVariant::Double)
		value << getPropertyValue<double>(property);

	return value;
	}

QList<int> QVNumericPlot::getPropertyCurvOrders(QString property) const
	{
	QList<int> order;
	return (order << 1);
	}

